@@ -22,9 +22,8 @@ def main():
     engine_path = 'sqlite:///' + sqlite_name
     engine = sqlalchemy.create_engine(engine_path, isolation_level='SERIALIZABLE')
 
-    data_dict = dict()
+    data_dict = {'value': cell_value}
     df = pd.DataFrame(data_dict)
-    df['value'] = cell_value
     df.to_sql(table_name, engine)
     return
 
